.. Note: The title "Overview" is special and is used in _static/layout.html

Overview
===============================

Welcome to the documentation of Smisk |release|.
More information can be found at `python-smisk.org <http://python-smisk.org/>`_


Starting points
--------------------

.. toctree::
  :maxdepth: 1
  
  library/index
  c-api/index


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
